@@ -12,8 +12,8 @@ from .archive import Archive
 class GeneralEvolutionaryAlgorithm(Algorithm):
     """ Basis Class for evolutionary algorithms """
 
-    def __init__(self, problem: Problem, name="General Evolutionary Algorithm"):
-        super().__init__(problem, name)
+    def __init__(self, problem: Problem, name="General Evolutionary Algorithm", evaluator_type=None):
+        super().__init__(problem, name, evaluator_type)
 
         self.parameters_length = len(self.problem.parameters)
 
@@ -27,11 +27,6 @@ class GeneralEvolutionaryAlgorithm(Algorithm):
 
         self.problem = problem
 
-        self.generator = None
-        self.selector = None
-        self.mutator = None
-        self.crossover = None
-
         # initial population size
         self.population_size = 0
 
@@ -42,8 +37,14 @@ class GeneralEvolutionaryAlgorithm(Algorithm):
         for individual in individuals:
             individual.features = self.features.copy()
 
+    def update_particles(self, individuals, offsprings):
+        for individual in individuals:
+            individual.features = self.features.copy()
+
     def gen_initial_population(self):
         individuals = self.generator.generate()
+        for individual in individuals:
+            individual.population_id = 0
         population = Population(individuals)
 
         # append to population
@@ -59,8 +60,13 @@ class GeneralEvolutionaryAlgorithm(Algorithm):
 
 class GeneticAlgorithm(GeneralEvolutionaryAlgorithm):
 
-    def __init__(self, problem: Problem, name="General Genetic-based Algorithm"):
-        super().__init__(problem, name)
+    def __init__(self, problem: Problem, name="General Genetic-based Algorithm", evaluator_type=None):
+        super().__init__(problem, name, evaluator_type)
+
+        self.generator = None
+        self.selector = None
+        self.mutator = None
+        self.crossover = None
 
     def generate(self, parents, archive=None):
         offsprings = []
@@ -102,7 +108,7 @@ class GeneticAlgorithm(GeneralEvolutionaryAlgorithm):
 
 class NSGAII(GeneticAlgorithm):
 
-    def __init__(self, problem: Problem, name="NSGA_II Evolutionary Algorithm"):
+    def __init__(self, problem: Problem, name="NSGA_II Evolutionary Algorithm", evaluator_type=None):
         """
          NSGA-II implementation as described in
 
@@ -110,7 +116,7 @@ class NSGAII(GeneticAlgorithm):
              multiobjective genetic algorithm: NSGA-II," in IEEE Transactions on Evolutionary Computation,
              vol. 6, no. 2, pp. 182-197, Apr 2002. doi: 10.1109/4235.996017
         """
-        super().__init__(problem, name)
+        super().__init__(problem, name, evaluator_type)
 
         self.options.declare(name='prob_cross', default=1.0, lower=0,
                              desc='prob_cross')
@@ -123,6 +129,8 @@ class NSGAII(GeneticAlgorithm):
                          'domination_counter': 0,
                          'front_number': 0, }
 
+        self.population_size = self.options['max_population_size']
+
         self.generator = RandomGenerator(self.problem.parameters)
         self.crossover = SimulatedBinaryCrossover(self.problem.parameters, self.options['prob_cross'])
         self.mutator = PmMutator(self.problem.parameters, self.options['prob_mutation'])
@@ -137,6 +145,8 @@ class NSGAII(GeneticAlgorithm):
 
         # non-dominated sort of individuals
         self.selector.fast_nondominated_sorting(population.individuals)
+        for individual in population.individuals:
+            self.problem.data_store.sync(individual)
 
         t_s = time.time()
         self.problem.logger.info(
@@ -155,7 +165,10 @@ class NSGAII(GeneticAlgorithm):
 
             # make the pareto dominance calculation and calculating the crowding distance
             self.selector.fast_nondominated_sorting(offsprings)
-            population.individuals = nondominated_truncate(offsprings, self.population_size)
+            for individual in population.individuals:
+                self.problem.data_store.sync(individual)
+            population.set_individuals(nondominated_truncate(offsprings, self.population_size))
+
 
         t = time.time() - t_s
         self.problem.logger.info("NSGA_II: elapsed time: {} s".format(t))
@@ -176,8 +189,8 @@ class EpsMOEA(GeneticAlgorithm):
                                  Minimum Reduce Hypervolume
     """
 
-    def __init__(self, problem: Problem, name="EpsMOEA Algorithm"):
-        super().__init__(problem, name)
+    def __init__(self, problem: Problem, name="EpsMOEA Algorithm", evaluator_type=None):
+        super().__init__(problem, name, evaluator_type)
 
         self.options.declare(name='prob_cross', default=0.6, lower=0,
                              desc='prob_cross')
@@ -209,7 +222,7 @@ class EpsMOEA(GeneticAlgorithm):
         # an archive to collect the eps-dominated solutions
         self.problem.archive = Archive(dominance=EpsilonDominance(epsilons=self.options['epsilons']))
 
-        self.evaluate(population.individuals)
+        self.evaluator.evaluate(population.individuals)
         self.add_features(population.individuals)
 
         # archiving the eps-dominating solutions
@@ -224,7 +237,7 @@ class EpsMOEA(GeneticAlgorithm):
             # generate and evaluate the next generation
             offspring = self.generate(population.individuals, archive=self.problem.archive)
 
-            self.evaluate(offspring)
+            self.evaluator.evaluate(offspring)
             self.add_features(offspring)
 
             # pop-acceptance procedure, the dominating offsprings will be preserved in the population and  in the
