@@ -28,12 +28,12 @@ class ScipyOpt(Algorithm):
         self.problem.populations.append(Population())
 
         # initial vector
-        x0 = np.array(self.problem.get_initial_values())
+        x0 = self.problem.get_initial_values()
 
         # optimization
         t_s = time.time()
         self.problem.logger.info("ScipyOpt: {}".format(self.options['algorithm']))
         minimize(self.evaluator.evaluate_scalar, x0, method=self.options['algorithm'], tol=self.options['tol'],
-                 bounds=self.options['bounds'], options={'maxiter':self.options['n_iterations']})
+                 bounds=self.options['bounds'], options={'maxiter': self.options['n_iterations']})
         t = time.time() - t_s
         self.problem.logger.info("ScipyOpt: elapsed time: {} s".format(t))
